MacOSPrintJobController class

Class representing a print job eventually returned by PlatformInAppWebViewController.printCurrentPage.

Inheritance
  • Object
  • PlatformInterface
  • MacOSPrintJobController

Constructors

MacOSPrintJobController(PlatformPrintJobControllerCreationParams params)
Constructs a MacOSPrintJobController.
MacOSPrintJobController.static()
Provide static access.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
Print job ID.
no setterinherited
onComplete ↔ PrintJobCompletionHandler?
A completion handler used to handle the conclusion of the print job (for instance, to reset state) and to handle any errors encountered in printing.
getter/setter pairinherited
params → PlatformPrintJobControllerCreationParams
The parameters used to initialize the PlatformPrintJobController.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → Future<void>
Cancels this print job. You can request cancellation of a queued, started, blocked, or failed print job.
inherited
dismiss({bool animated = true}) → Future<void>
Dismisses the printing-options sheet or popover.
inherited
dispose() → Future<void>
Disposes the print job.
getInfo() → Future<PrintJobInfo?>
Gets the PrintJobInfo that describes this job.
isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
inherited
isMethodSupported(PlatformPrintJobControllerMethod method, {TargetPlatform? platform}) → bool
Check if the given method is supported by the defaultTargetPlatform or a specific platform.
inherited
isPropertySupported(dynamic property, {TargetPlatform? platform}) → bool
Check if the given property is supported by the defaultTargetPlatform or a specific platform. The property should be one of the PlatformPrintJobControllerProperty or PlatformPrintJobControllerCreationParamsProperty values.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restart() → Future<void>
Restarts this print job. You can request restart of a failed print job.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited